$TITLE  Model mcp_cdv.gms: Introduction of the Basic Vector Syntax


TABLE BENCH(*,*)  Benchmark financial flows 
                X       Y        W           CONS
        X     100             -100    
        Y             100     -100    
        W                      200           -200
        L     -40     -60                     100
        K     -60     -40                     100;

SET     I       Produced goods          /X, Y/,
        F       Factors of production   /L, K/;

ALIAS (I,J), (F,FF);

PARAMETER       Y0(I)           Benchmark sectoral output,
                FD0(F,I)        Benchmark factor demands,
                C0(I)           Benchmark consumption demand, 
                E(F)            Factor endowments, 
                W0              Benchmark total consumption,
		ALPHA(F,I)      Factor input benchmark value share,
                BETA(I)         Benchmark consumption value share;


*       Extract values from table
Y0(I)         = BENCH(I,I);          
FD0(F,I)      = -BENCH(F,I);
C0(I)         = -BENCH(I,"W");       
W0            = SUM(I, C0(I));
E(F)          = BENCH(F,"CONS");     

ALPHA(F,I)	=	FD0(F,I) / Y0(I);
BETA(I)		=	C0(I) / SUM(F, E(F));

DISPLAY Y0, FD0, C0, E, ALPHA, BETA;


POSITIVE VARIABLES
        Y(I)		Production activity level
        W		Welfare index

        PW		Welfare price index
        PC(I)		Commodity price 
        PF(F)		Factor price

	RA		Consumer income level

EQUATIONS
        PRF_Y(I)	Zero profit in production
	PRF_W		Zero profit in welfare formation

        MKT_Y(I)	Supply-demand balance for commodities
        MKT_F(F)	Supply-demand balance for factors
        MKT_W		Supply-demand balance for welfare composite

        I_RA		Income definition for RA;



*       Zero profit conditions are produced for all of the production
*       sectors.  These are interpreted as:

*               Cost of Production Gross of Tax  =  Value of Output

PRF_Y(I)..         Y0(I) *SUM(F, PF(F)**alpha(F,I))  =E= Y0(I) * PC(I);

PRF_W..		   W0 * SUM(I, PC(I)**beta(i))=E= W0 * PW;

*       Market clearance conditions for each of the final goods and
*       primary factors.  These are interpreted as:

*               Output plus Initial Endowment  = Intermediate + Final Demand

MKT_Y(I)..      Y0(I) * Y(I) =E= 100 * W * PW/PC(I);

MKT_W..         W0 * W =E= RA / PW;

MKT_F(F)..      E(F)  =E= SUM(I, FD0(F,I)* Y(I) * PC(I)/PF(F));


*       Income balance states that the level of expenditure (RA)
*       equals the value of factor income plus tax revenue:

I_RA..        RA =E= SUM(F, E(F)*PF(F)); 


MODEL ALGEBRAIC /PRF_Y.Y, PRF_W.W, MKT_Y.PC, MKT_W.PW, MKT_F.PF,I_RA.RA /;

*       Check the benchmark (benchmark replication):

ALGEBRAIC.ITERLIM = 0;

Y.L(I)=1;  W.L=1; PC.L(I)=1; PF.L(F) = 1; PW.L = 1; RA.L=200;


SOLVE ALGEBRAIC USING MCP;


