$TITLE: CLOSED ECONOMY 2*2 WITH SEPARABLE NESTED CES-FUNCTIONS IN MCP SYNTAX

$ontext
This example illustrates that the MCP formulation of GE problems can 
get rather tedious when nested functional forms are employed (need to apply 
chain rule for the derivation of compensated demand functions).


Here we assume 2 level separable nested CES functions in production.

*       The X sector production function is a two-level CES.
*       In the KY, K and Y form a Cobb-Douglas aggregate.
*       In the top level, L and KY(K,Y) have an elasticity of 
*       substitution equal to 0.5

*       The Y sector production function is a two-level CES.
*       In the KX, K and X form a Cobb-Douglas aggregate.
*       In the top level, L and KX(K,X) have an elasticity of 
*       substitution equal to 0.5


For the specification of NNCES functions which allow the use of 
arbitrary AUES between inputs see Rutherford/Perroni (EER 1997).

                 Production Sectors          Consumers
   Markets  |    X       Y        W    |       CONS
   ------------------------------------------------------
       PX   |  120     -20     -100    |
       PY   |  -20     120     -100    |
       PW   |                   200    |       -200
       PL   |  -40     -60             |        100
       PK   |  -60     -40             |        100
    ------------------------------------------------------
$offtext

SCALARS
        TL_X    Labor input tax in X production /0/     
        TL_Y    Labor input tax in Y production /0/;

POSITIVE VARIABLES
        X    Activity level for X sector
        Y    Activity level for Y sector
        W    Activity level for utility production(Hicksian welfare index)

        PX   Price index for X commodity
        PY   Price index for Y commodity
        PL   Price index for labor
        PK   Price index for capital
        PW   Price index for welfare (expenditure funtion) 

        RA   Consumer income level;


EQUATIONS
        PRF_X   Zero profit for sector X
        PRF_Y   Zero profit for sector Y
        PRF_W   Zero profit for sector W (Hicksian welfare index)

        MKT_X   Supply-demand balance for commodity X
        MKT_Y   Supply-demand balance for commodity Y
        MKT_L   Supply-demand balance for primary factor L
        MKT_K   Supply-demand balance for primary factor L
        MKT_W   Supply-demand balance for aggregate demand

        I_RA    Income definition for RA;




EQUATIONS
        PRF_X   Zero profit for sector X
        PRF_Y   Zero profit for sector Y
        PRF_W   Zero profit for sector W (Hicksian welfare index)

        MKT_X   Supply-demand balance for commodity X
        MKT_Y   Supply-demand balance for commodity Y
        MKT_L   Supply-demand balance for primary factor L
        MKT_K   Supply-demand balance for primary factor L
        MKT_W   Supply-demand balance for aggregate demand

        I_RA  Income definition for RA;

*.$ontext
PRF_X.. 120 * ( 1/3 * (PL*(1+TL_X))**(1-0.5) +
                2/3 * (PK**0.75 * PY**0.25)**(1-0.5) )**(1/(1-0.5))
                        =E= 120 * PX;

PRF_Y.. 120 * ( 1/2 * (PL*(1+TL_Y))**(1-0.75) +
                1/2 * (PK**(2/3)* PX**(1/3))**(1-0.75) )**(1/(1-0.75))  
                        =E= 120 * PY;

PRF_W.. 200 * PX**0.5 * PY**0.5 =E= 200 * PW;

MKT_X.. 120 * X =E= 100 * W * PX**0.5 * PY**0.5 / PX + 
     20*Y*(PY/(PK**(2/3)* PX**(1/3)))**0.75* PK**(2/3)* PX**(1/3)/PX;

MKT_Y.. 120 * Y =E= 100 * W * PX**0.5 * PY**0.5 / PY +
     20*X*(PX/(PK**0.75* PY**0.25))**0.5* PK**0.75* PY**0.25/PY;

MKT_W.. 200 * W =E= RA / PW;

MKT_L.. 100  =E= 40 * X * (PX/((1+TL_X)*PL))**0.5 +
                 60 * Y * (PY/((1+TL_Y)*PL))**0.75;

MKT_K.. 100 =E=  60 * X * (PX/(PK**0.75 * PY**0.25))**0.5
                       * (PK**0.75 * PY**0.25) /PK
                 + 40 * Y *(PY/(PK**(2/3) * PX**(1/3)))**0.75
                       * PK**(2/3) * PX**(1/3) /PK;

I_RA.. RA =E= 100*PL + 100*PK + 
  TL_X * PL *40 * X * (PX/((1+TL_X)*PL))**0.5 +
  TL_Y * PL *60 * Y * (PY/((1+TL_Y)*PL))**0.75;
                  
MODEL ALGEBRAIC /PRF_X.X, PRF_Y.Y, PRF_W.W, MKT_X.PX, MKT_Y.PY, MKT_L.PL, 
                 MKT_K.PK, MKT_W.PW, I_RA.RA /;

*       Check the benchmark:

        X.L=1; Y.L=1; W.L=1; PL.L = 1;PX.L=1; PY.L=1; PK.L=1; PW.L=1; RA.L=200;

        TL_X = 0; TL_Y = 0; 
        SOLVE ALGEBRAIC USING MCP;

*	Fix wage as the numeraire
PL.FX = 1;

*       Solve the tax counterfactual:
        TL_X = 1; TL_Y = 0.5; 
        SOLVE ALGEBRAIC USING MCP;


