$TITLE	 A simple maquette for activity analysis in MCP

$ontext
Here we demonstrate the MCP implementation of a CGE model
featuring discrete activity analysis across various
technologies that supply the same good.

In our concret example, the only good that is produced is
energy E which requires inputs of a MACRO good X and 
technology-specific capital R. We do no start from a balanced 
benchmark. Instead we have the following information on 
technologies, preferences and initial endowments:

(i) Energy supply technologies are Leontief with inputs R and X. 
The per-unit-output demands in (X,R) are as follows:
e(T) = min(C(T)/4, 3/4)

(ii) Endowments are given as
X: 94; E: 1; R(T) = 3;

(iii) Preferences are Cobb-Douglas in X and E:
value share of X: (95/100); value share of E: (5/100)


We use this information to compute a consistent 
equilibrium where technologies are active or inactive
depending on their profitability.

$offtext


SET		T	TECHNOLOGIES	/T0, T1, T2/;
PARAMETER	C(T)	COSTS		/T0 1,T1 4, T2 5/;

POSITIVE VARIABLES
	E(T)		Energy supply by technology T
	PE		Price of energy
	PX		Price index of other goods
	PR(T)		Rental rate on capital

	RA		Income level of representative consumer;

EQUATIONS
	ZPRF_E(T)	Zero profit condition

	MKT_PE		Market clearance for energy
	MKT_PR		Market clearnace for technology specfic capital
	MKT_PX		Market clearance for macro good

	INCOME		Income constraint;



ZPRF_E(T)..	(3/4)*PR(T) + (C(T)/4)*PX =E= PE;

MKT_PE..	SUM(T, E(T)) + 1 =E= 5* (RA/100)/PE;	
MKT_PR(T)..	3		 =E= (3/4)*E(T);
MKT_PX..	94		 =E= SUM(T, (C(T)/4)*E(T))+ 95*(RA/100)/PX ;
INCOME..	94*PX + SUM(T, PR(T)*3) + PE	=E= RA; 


PX.FX = 1; PE.LO = 1.e-5;
RA.L = 100; PE.L = 1; PX.L = 1; PR.L(T) = 1; E.L(T) = 1;

MODEL	ACTIVITY /ZPRF_E.E, MKT_PE.PE, MKT_PR.PR, MKT_PX.PX, INCOME.RA /;

ACTIVITY.ITERLIM = 1000;
SOLVE ACTIVITY USING MCP;
