$TITLE  Model M2x2x1_sub: Illustration of quantity constraint (weak inequality)

$if not setglobal L1_level	$setglobal L1_level	0


TABLE BENCH(*,*)  Benchmark financial flows 
                Y1     Y2       CONS
        Y1      40		-40
        Y2             40	-40
        L     -20     -10        30 
        K     -20     -30        50 ;

SET     I       Produced goods          /Y1, Y2/,
        F       Factors of production   /L, K/;

ALIAS (I,J), (F,FF);

SCALAR	L1_LEVEL		Targeted percentage increase in L1 employment /%L1_LEVEL%/;

PARAMETER       Y0(I)           Benchmark sectoral output,
                FD0(F,I)        Benchmark factor demands,
                C0(I)           Benchmark consumption demand, 
		K0		Capital endowment,
		L0		Labor endowment,
		ALPHA(F,I)      Factor input benchmark value share,
                BETA(I)         Benchmark consumption value share
		M0		Benchmark income of representative agent;


*       Extract values from table
Y0(I)		= BENCH(I,I);          
FD0(F,I)	= -BENCH(F,I);
C0(I)		= -BENCH(I,"CONS");       

K0		= BENCH("K","CONS");     
L0		= BENCH("L","CONS");     
M0		= K0 + L0;

ALPHA(F,I)	= FD0(F,I) / Y0(I);
BETA(I)		= C0(I) / M0;


DISPLAY Y0, FD0, C0, ALPHA, BETA;


POSITIVE VARIABLES
        Y(I)		Production activity level

        p(I)		Commodity price 
        w		Wage rate
	r		Rental rate

	M		Consumer income level

	tau(i)		Subsidy rate ;


EQUATIONS
        PRF_Y(I)	Zero profit in production

        MKT_Y(I)	Supply-demand balance for commodities
        MKT_L		Supply-demand balance for labor
        MKT_K		Supply-demand balance for capital

        RA_M		Income definition for RA
	
	L_TARGET(I)	Minimum sectoral employment level;


*       Zero profit conditions are produced for all of the production
*       sectors.  These are interpreted as:

*               Cost of Production Gross of Tax  =  Value of Output

PRF_Y(I)..         Y0(I) * (w*(1-TAU(I)))**alpha("L",I)* (r**alpha("K",I))  =E= Y0(I) * P(I);

*       Market clearance conditions for each of the final goods and
*       primary factors.  These are interpreted as:

*               Output plus Initial Endowment  = Intermediate + Final Demand

MKT_Y(I)..      Y0(I) * Y(I) =E= C0(I) * M/(P(I)*M0);

MKT_L..		L0  =E= SUM(I, FD0("L",I)* Y(I) * P(I)/(w*(1-TAU(I))));

MKT_K..		K0  =E= SUM(I, FD0("K",I)* Y(I) * P(I)/r);


*       Income balance states that the level of expenditure (RA)
*       equals the value of factor income plus tax revenue:

RA_M..		M =E=      L0*w + K0*r
			 - SUM(I, w*TAU(I)* (FD0("L",I)* Y(I) * P(I)/(w*(1-TAU(I)))));


L_TARGET(I)..	FD0("L",I)* Y(I) * P(I)/(w*(1-TAU(I))) =G= FD0("L",I)*(1 + L1_LEVEL);

MODEL M2x2x1_sub /PRF_Y.Y, MKT_Y.P, MKT_L.w, MKT_K.r, RA_M.M, L_TARGET.tau /;

*       Check the benchmark (benchmark replication):
Y.L(I)=1;  P.L(I)=1; r.FX=1; w.L=1; M.L=M0; tau.fx(i) = 0;

M2x2x1_sub.ITERLIM = 0;
SOLVE M2x2x1_sub USING MCP;


*	Proceed with Subsidy Counterfactual

M2x2x1_sub.ITERLIM = 1000;

TAU.LO("Y1") = 0;
TAU.UP("Y1") = 1;

SET SC		Target levels	/T0, T05, T10, T15, T20, T25, T30, T35, T40, T45, T50/;

PARAMETERS	
		LEVEL(SC)	Target employment levels in sector 1 as percentage increase over BMK
				/T0 0, T05 5, T10 10, T15 15, T20 20, T25 25, T30 30, T35 35, T40 40, T45 45, T50 50/
		SUBSIDY(SC)	Subsidy rate in percent of real wage,
		WELFARE(SC)	Welfare implications as percentage change in HEV of income;

LOOP (SC,
	L1_LEVEL = LEVEL(SC)/100;
SOLVE M2x2x1_sub USING MCP; 

SUBSIDY(SC)	= ROUND(100*SUM(I, TAU.L(I)), 1);
WELFARE(SC)	= ROUND(100*((M.L/(PROD(I,P.L(I)**BETA(I))))/M0 - 1), 1);
);

DISPLAY SUBSIDY, WELFARE;
