$TITLE: CLOSED ECONOMY 2*2 WITH AUXILIARY CONSTRAINTS IN MPSGE SYNTAX 


$ontext
The standard Arrow-Debreu framework can be extended by price or quantity 
constraints. Price constraints are associated with endowment multipliers
to accomodate a rationing equilibrium. Quantity constraints are associated
with endogenous taxes which adjust prices such that the quantity constraint
is met.

Below we apply an endogenous subsidy such that labor input in the X sector is 
increase by 10 % in the counterfactual (as compared to the benchmark).


TABLE BMFLOW(*,*) BENCHMARK FLOWS

               X       Y       W       RA     ROWSUM
  X          100            -100                     0
  Y                  100    -100                     0
  UTIL                       200      -200           0
  L          -40     -60               100           0
  K          -60     -40               100           0
  COLSUM       0       0        0        0 ;
$offtext       


SCALAR          CF      Flag for counterfactual scenario /0/;

PARAMETER       REPORT  Report parameter for labor input in X sector;


$ONTEXT
$MODEL:SUBS

$SECTORS:
        X    ! Activity level for X sector
        Y    ! Activity level for Y sector
        W    ! Activity level for utility production(Hicksian welfare index)


$COMMODITIES:
        PX   ! Price index for X commodity
        PY   ! Price index for Y commodity
        PL   ! Price index for labor
        PK   ! Price index for capital
        PW   ! Price index for welfare (expenditure funtion) 

$CONSUMERS:
        RA   ! Consumer income level

$AUXILIARY:
        SL$CF  ! Endogenous subsidy     

$PROD:X s:1
        O:PX    Q:100
        I:PL    Q:40        A:RA N:SL$CF M:(-1)$CF      
        I:PK    Q:60        

$PROD:Y s:1
        O:PY    Q:100
        I:PL    Q:60       
        I:PK    Q:40        

$PROD:W s:1
        O:PW    Q:200
        I:PX    Q:100       
        I:PY    Q:100       

$DEMAND:RA
        D:PW    Q:200
        E:PL    Q:100
        E:PK    Q:100

$CONSTRAINT:SL$CF
        40 * X * PX/(PL*(1-SL)) =G= 1.1*40;

$OFFTEXT

$SYSINCLUDE mpsgeset SUBS

        SUBS.WORKSPACE = 4;

* Do benchmark replication:
        SUBS.ITERLIM = 0;
$INCLUDE SUBS.GEN
        SOLVE SUBS USING MCP;

REPORT("BMK") = 40 * X.L * PX.L/PL.L;


* Do counterfactual
        SUBS.ITERLIM = 1000;
CF = 1; 
$INCLUDE SUBS.GEN
        SOLVE SUBS USING MCP;

REPORT("CF") = 40 * X.L * PX.L/(PL.L*(1-SL.L));

DISPLAY REPORT;
