$TITLE: CLOSED ECONOMY 2*2 WITH SEPARABLE NESTED CES-FUNCTIONS IN MPSGE

$ontext
This example illustrates how convenient MPSGE is for the formulation of
nested CES functional forms as compared to the standard MCP syntax.
Whereas in the MCP form we have to write down tedious cost and demand 
functions these formulae are  automatically generated within MPSGE.

The nesting structure is indicated on the first line of the $PROD block
(or $DEMAND block). For difficult nesting structures it is possible to
make references within the substitution elasticities:

*       Syntax issues regarding aggregate labels:
*
*       (i)   Labels may have 1-4 characters.
*       (ii)  These names are not case sensitive ("va:" = "VA:").
*       (iii) Names s: and t: are reserved for top level input and
*               output (substitution and transformation) aggregates.


                 Production Sectors          Consumers
   Markets  |    X       Y        W    |       CONS
   ------------------------------------------------------
       PX   |  120     -20     -100    |
       PY   |  -20     120     -100    |
       PW   |                   200    |       -200
       PL   |  -40     -60             |        100
       PK   |  -60     -40             |        100
    ------------------------------------------------------
 
$offtext

SCALARS
         TL_X   /0/
         TL_Y   /0/;

$ONTEXT

$MODEL: NESTED

$SECTORS:
        X       ! Activity level for sector X
        Y       ! Activity level for sector Y
        W       ! Activity level for sector W (Hicksian welfare index)

$COMMODITIES:
        PX      ! Price index for commodity X
        PY      ! Price index for commodity Y
        PL      ! Price index for primary factor L
        PK      ! Price index for primary factor K
        PW      ! Price index for welfare (expenditure function)

$CONSUMERS:
        CONS    ! Income level for consumer CONS

*       MPSGE is based on the use of composite CES functions.

*       The X sector production function is a two-level CES.
*       In the KY, K and Y form a Cobb-Douglas aggregate.
*       In the top level, L and KY(K,Y) have an elasticity of 
*       substitution equal to 0.75

$PROD:X s:0.5  KY:1
        O:PX   Q:120
        I:PY   Q:20  KY:
        I:PL   Q:40             A:CONS  T:TL_X
        I:PK   Q:60  KY:

*       The Y sector production function is a two-level CES.
*       In the KX, K and X form a Cobb-Douglas aggregate.
*       In the top level, L and KX(K,X) have an elasticity of 
*       substitution equal to 0.5


$PROD:Y s:0.75  KX:1
        O:PY   Q:120
        I:PX   Q: 20  KX:
        I:PL   Q: 60            A:CONS  T:TL_Y
        I:PK   Q: 40  KX:

$PROD:W s:1
        O:PW   Q:200
        I:PX   Q:100
        I:PY   Q:100

$DEMAND:CONS
        D:PW   Q:200
        E:PL   Q:100
        E:PK   Q:100

$OFFTEXT
$SYSINCLUDE mpsgeset NESTED

        NESTED.WORKSPACE = 4;

*       Benchmark replication:
        NESTED.ITERLIM = 0;
$INCLUDE NESTED.GEN
        SOLVE NESTED USING MCP;

* Task:
* (i)   Apply a 100% labor tax for X and a 50 % labor tax for Y;
* (ii)  Make sure that MPSGE and MCP (see: mcp_nest) formulation generate the
*       same results

*	Relax the itteration limit
        NESTED.ITERLIM = 2000;

*	Impose new taxes
        TL_X = 1; TL_Y = 0.5; 

*       Fix the wage rate as numeraire: 
        PL.FX = 1;


*       Solve the tax counterfactual:
$INCLUDE NESTED.GEN

        SOLVE NESTED USING MCP;


