$TITLE: CLOSED ECONOMY 2*2 WITH BENCHMARK TAXES IN MPSGE VECTOR SYNTAX

$ontext
This example illustrates the treatment of BMK taxes on inputs and
outputs. It is important to be aware that tax rates are interpreted
differently for inputs and outputs:
- tax rates on inputs are specified on a net basis
uc = p*(1 + t)
- tax rates on outputs are specified on a gross basis
uc = p*(1 - t) 


MPSGE uses references prices and quantities for function calibration.
Taxes do not change the underlying technologies or preferences. The important
lesson is to keep track of what reference prices (and related quantities) firms
and consumer face in the benchmark.
$offtext

TABLE BMFLOW(*,*) BENCHMARK FLOWS
               X       Y       W       CONS     ROWSUM
  X          100            -100                     0
  Y                  100    -100                     0
  UTIL                       200      -200           0
  L          -10     -60                70           0
  K          -60     -40               100           0
  TAX_L      -10                        10
  TAX_PROD   -20                        20
* COLSUM       0       0        0        0 ;



*---------- Formulation in MPSGE - Scalar Syntax ------------------------------
$ONTEXT
$MODEL:BMK_TAX_S

$SECTORS:
        X       ! Activity level for sector X
        Y       ! Activity level for sector Y
        W       ! Activity level for sector W (Hicksian welfare index)

$COMMODITIES:
        PX      ! Price index for commodity X
        PY      ! Price index for commodity Y
        PL      ! Price index for primary factor L
        PK      ! Price index for primary factor K
        PW      ! Price index for welfare (expenditure function)

$CONSUMERS:
        CONS    ! Income level for consumer CONS

$PROD:X s:1
        O:PX  Q:100     P:0.8   A:CONS  T:0.2
        I:PL  Q:10      P:2     A:CONS  T:1
        I:PK  Q:60 

$PROD:Y s:1
        O:PY  Q:100
        I:PL  Q:60
        I:PK  Q:40

$PROD:W s:1
        O:PW   Q:200
        I:PX   Q:100
        I:PY   Q:100

*       Here we represent final excess demand.  This function
*       represents preferences (using reference demands), and 
*       initial factor endowments:

$DEMAND:CONS
        D:PW   Q:200
        E:PL   Q: 70
        E:PK   Q:100

$OFFTEXT

$SYSINCLUDE mpsgeset BMK_TAX_S
        BMK_TAX_S.WORKSPACE = 4;

* Do a benchmark replication check:
        BMK_TAX_S.ITERLIM = 0;
$INCLUDE BMK_TAX_S.GEN
        SOLVE BMK_TAX_S USING MCP;



*---------- Formulation in MPSGE - Vector Syntax ------------------------------
$ontext
It might be usefuld to write (large-scale) vector syntax models it is helpful
to write models from "inside-out":
(i)     First, write down the MPSGE model
(ii)    Second, define associated SETS, PARAMETERS and SCALARS outside in the
        GAMS environment
$offtext


SETS    I       Produced goods  /X, Y/,
        F       Factors of production /L labour, K capital/; 

ALIAS (FF,F), (I,J);


PARAMETERS      YBAR(I)         Benchmark output levels
                FDBAR(F,I)      Benchmark factor inputs
                CBAR(I)         Benchmark final demands
                ENDOW(F)        Factor endowments
                UBAR            Benchmark expenditure (consumption)
                TAX_IN(F,I)     Input tax on factors
                TAX_OUT(I)      Output tax on commodities    
                PF_BAR(F,I)     Reference factor price
                PI_BAR(I)       Reference output price;

*     Extract values from the table:
YBAR(I)         = BMFLOW(I,I);
FDBAR(F,I)      = -BMFLOW(F,I);
CBAR(I)         = -BMFLOW(I,"W");
UBAR            = SUM(I,CBAR(I));
ENDOW(F)        = BMFLOW(F,"CONS");

TAX_IN(F,I)     = 0;
TAX_OUT(I)      = 0;
PF_BAR(F,I)     = 1;
PI_BAR(I)       = 1;


TAX_OUT(I)      = - BMFLOW("TAX_PROD",I)/BMFLOW(I,I);
PI_BAR(I)       = 1 - TAX_OUT(I);


TAX_IN("L",I)   = - BMFLOW("TAX_L",I)/(-BMFLOW("L",I));
PF_BAR(F,I)     = 1 + TAX_IN(F,I);

DISPLAY PF_BAR, PI_BAR, TAX_IN, TAX_OUT;


*---------- Formulation in MPSGE - Vector Syntax ------------------------------
$ONTEXT
$MODEL:BMK_TAX_V

$SECTORS:
        Z(I)   ! Activity level for sectors 
        U      ! Activity level for utility production(Hicksian welfare index)

$COMMODITIES:
        P(I)  ! Price index for commodities
        PF(F) ! Price index for factors
        PU    ! Price index for welfare (expenditure funtion) 

$CONSUMERS:
        RA      ! Representative consumer

$PROD:Z(I) s:1
        O:P(I)        Q:YBAR(I)    P:PI_BAR(I)   A:RA T:TAX_OUT(I)           
        I:PF(F)       Q:FDBAR(F,I) P:PF_BAR(F,I) A:RA T:TAX_IN(F,I)

$PROD:U s:1
        O:PU         Q:UBAR
        I:P(I)       Q:CBAR(I)

$DEMAND:RA
        D:PU           Q:UBAR
        E:PF(F)        Q:ENDOW(F)

$OFFTEXT

$SYSINCLUDE mpsgeset BMK_TAX_V

        BMK_TAX_V.WORKSPACE = 4;

* Do the benchmark replication
        BMK_TAX_V.ITERLIM = 0;
$INCLUDE BMK_TAX_V.GEN
        SOLVE BMK_TAX_V USING MCP;


* Set taxes in the counterfactual to zero
TAX_OUT(I)  = 0;          
TAX_IN(F,I) = 0;


        BMK_TAX_V.ITERLIM = 2000;
$INCLUDE BMK_TAX_V.GEN
        SOLVE BMK_TAX_V USING MCP;
