$TITLE: SOE - Armington Trade


$ontext
Production Sectors                      Consumer
Markets   |     X1      X2      E       M        W       CONS
------------------------------------------------------------------
P1        |     150             -100    50      -100
P2        |             50      -25     75      -100
PL        |     -100    -20                              120
PK        |     -50     -30                               80
PW        |                                      200    -200
PFX       |                     125     -125
------------------------------------------------------------------
$offtext


SCALAR          ESUBDM		Armington elasticity of substitution / 4 /
		t1		elasticity of transformation /2/
		TL		labour tax /0/;

PARAMETER
		vs_lx1  value share of L in X1
		vs_lx2	value share of L in X2
		sd_am1	value share of domestic good in armington good 1
		sd_am2	value share of domestic good in armington good 2
		sd_x1	value share of domestic supply in sector x1
		sd_x2	value share of domestic supply in sector x2;
		

vs_lx1 = 2/3;
vs_lx2 = 2/5;
sd_am1 = 1/2;
sd_am2 = 1/4;
sd_x1  = 1/3;
sd_x2  = 1/2;



POSITIVE VARIABLES
        X1       Production index for good 1
        X2       Production index for good 2
        AM1      Armington good index for good 1
        AM2      Armington good index for good 2
        W        Welfare index 

	P1       Price index for good 1
        P2       Price index for good 2  
	PA_1     Price index for imported good 1
        PA_2     Price index for imported good 2
        PFX      Real exchange rate index
        PW       Welfare price index
        PL       Wage index
        PK       Capital rental index

        CONS     Income level for representative agent;


        


EQUATIONS
        PRF_X1   Zero profit for sector X1
        PRF_X2   Zero profit for sector X2
	PRF_AM1	 Zero profit for Armington good 1
	PRF_AM2	 Zero profit for Armington good 2
        PRF_W    Zero profit for sector W (Hicksian welfare index)

        MKT_X1   Supply-demand balance for commodity X1
        MKT_X2   Supply-demand balance for commodity X2
	MKT_PA1  Supply-demand balance for commodity AM1
	MKT_PA2	 Supply-demand balance for commodity AM2
		
        MKT_L    Supply-demand balance for primary factor L
        MKT_K    Supply-demand balance for primary factor L
        MKT_W    Supply-demand balance for aggregate demand

	BAL_OP	 Balance of Payment constraint

        I_CONS   Income definition for RA;



*       Zero profit conditions are produced for all of the production
*       sectors.  These are interpreted as:

*               Cost of Production Gross of Tax  =  Value of Output

PRF_X1..        (PL*(1+TL))**vs_lx1 * PK**(1-vs_lx1)  =E= (sd_x1*P1**(1+t1) + (1-sd_x1)*PFX**(1+t1))**(1/(1+t1));

PRF_X2..        PL**vs_lx2 * PK**(1-vs_lx2)  =E= sd_x2*P2 + (1-sd_x2)*PFX;

PRF_AM1	..	sd_am1*P1 + (1-sd_am1)*PFX =E= PA_1; 

PRF_AM2	..	sd_am2*P2 + (1-sd_am2)*PFX =E= PA_2; 

PRF_W..         PA_1**0.5 * PA_2**0.5  =E= PW;



*       Market clearance conditions for each of the final goods and
*       primary factors.  These are interpreted as:

*               Output plus Initial Endowment  = Intermediate + Final Demand

MKT_X1..        X1*(P1/((PL*(1+TL))**vs_lx1*PK**(1-vs_lx1)))**t1 =E= AM1;

MKT_X2..        X2 =E= AM2;

MKT_W..         200 * W  =E= CONS / PW;

MKT_L..         120  =E= 100 * X1 * (PL*(1+TL))**vs_lx1 * PK**(1-vs_lx1)/PL/(1+TL)
				+ 20 * X2 * PL**vs_lx2 * PK**(1-vs_lx2)/PL;

MKT_K..         80 =E= 50 * X1 * (PL*(1+TL))**vs_lx1 * PK**(1-vs_lx1)/PK
				+  30 * X2 * PL**vs_lx2 * PK**(1-vs_lx2)/PK;

MKT_PA1..		AM1 =E= W * PW/PA_1;

MKT_PA2..		AM2 =E= W * PW/PA_2;
                        

* balance of payment

BAL_OP..		100*X1*(PFX/((PL*(1+TL))**vs_lx1*PK**(1-vs_lx1)))**t1 + 25*X2 =E= 50*AM1 + 75*AM2;


*       Income balance states that the level of expenditure (RA)
*       equals the value of factor income plus tax revenue:

I_CONS..        CONS =E= 120*PL + 80*PK + TL*PL*100*X1*(PL*(1+TL))**vs_lx1*PK**(1-vs_lx1)/(PL*(1+TL)); 


MODEL ALGEBRAIC /PRF_X1.X1, PRF_X2.X2, PRF_W.W, MKT_X1.P1, MKT_X2.P2, MKT_L.PL, 
                 MKT_K.PK, MKT_W.PW, I_CONS.CONS, PRF_AM1.AM1, PRF_AM2.AM2,
		 MKT_PA1.PA_1, MKT_PA2.PA_2, BAL_OP.PFX/;

*       Check the benchmark (benchmark replication):

ALGEBRAIC.ITERLIM = 0;

X1.L=1; X2.L=1; W.L=1; AM1.L=1; AM2.L=1; PFX.L=1;
P1.L=1; P2.L=1; PK.L=1; PL.L=1; PW.L=1; PA_1.L=1; PA_2.L=1; CONS.L=200;

SOLVE ALGEBRAIC USING MCP;


*	Illustrative counterfactual: Apply a 10% ad-valorem labor tax
TL = 0.1;
PW.FX = 1;
ALGEBRAIC.ITERLIM = 1000;
SOLVE ALGEBRAIC USING MCP;
