$TITLE  Small open economy model.  Two goods, two factors - HO trade

$ontext

This model illustrates the representation of international trade 
flows in an open economy model.  In this model, the foreign country
is not explicitly modelled.  Trade possibilities are modelled by four
activities which transform domestic goods into "foreign exchange" and
vice versa.

This model is based on the Heckscher-Ohlin assumption that domestic,
imported and exported goods are perfect substitutes.

Two possible trade activities, exports of good 2 and imports of good
1, are idle.  We presume that the export price for good 2 less than
one and the import price for good 1 is greater than one.

                Production Sectors                      Consumer

Markets   |     X1      X2      E1      M2      W       CONS
------------------------------------------------------------------
P1        |     150             -50             -100
P2        |             50              50      -100
PL        |     -100    -20                             120
PK        |     -50     -30                             80
PW        |                                     200     -200
PFX       |                     50      -50
------------------------------------------------------------------

$offtext

*	OPTION MCP=MILES;

SCALAR
		PE2     Export price of good 2 / 0.99/
		PM1     Import price of good 1 / 1.01/
		PE1     Export price of good 1 / 1   /
		PM2     Import price of good 2 / 1   /	
		TM2     Import tariff for good 2 / 0/;

POSITIVE VARIABLES
		X1      Production index for good 1
        X2      Production index good 2
        E1      Export level of good 1
        E2      Export level of good 2
        M1      Import level of good 1
        M2      Import level of good 2
        W       Welfare index 
	P1      Price index for good 1
        P2      Price index for good 1        
        PFX     Read exchange rate index
        PW      Welfare price index
        PL      Wage index
        PK      Capital rental index
	RA	Income of representative agent;
		
EQUATIONS
        PRF_X1  Zero profit for sector X1
        PRF_X2  Zero profit for sector X2
        PRF_W   Zero profit for sector W (Hicksian welfare index)
	PRF_E1	Zero profit for E1
	PRF_E2	Zero profit for E2
	PRF_M1	Zero profit for M1
	PRF_M2	Zero profit for M2
	MKT_X1  Supply-demand balance for commodity X1
        MKT_X2  Supply-demand balance for commodity X2
        MKT_L   Supply-demand balance for primary factor L
        MKT_K   Supply-demand balance for primary factor L
        MKT_W   Supply-demand balance for aggregate demand
	MKT_PFX	Balance of payments
        I_RA    Income definition for RA;

PRF_X1..        PL**(2/3)*PK**(1/3) =E= P1;

PRF_X2..        PL**0.4*PK**0.6 =E= P2;

PRF_W..         P1**0.5 * P2**0.5 =E= PW;

PRF_E1..	P1 =G= PE1 * PFX;

PRF_E2..	P2 =G= PE2 * PFX;

PRF_M1..	PM1 * PFX =G= P1;

PRF_M2..	PM2 * PFX * (1+TM2) =G= P2;

MKT_X1..        X1*150 + M1 - E1 =E= 100 * W * PW/P1;

MKT_X2..        X2*50 + M2 - E2 =E= 100 * W * PW/P2;

MKT_W..         200 * W =E= RA / PW;

MKT_L..         120  =E= 100 * X1 * P1/PL + 20 * X2 * P2/PL;

MKT_K..         80  =E=  50 * X1 * P1/PK + 30 * X2 * P2/PK;

MKT_PFX..	E1*PE1 + E2*PE2 =E= M1*PM1 + M2*PM2;
                        
I_RA..		RA =E= 120 * PL + 80 * PK + M2 * PM2 * PFX * TM2;

MODEL HOTRADE /PRF_X1.X1, PRF_X2.X2, PRF_W.W, PRF_E1.E1, PRF_E2.E2, PRF_M1.M1, PRF_M2.M2, 
			 MKT_X1.P1, MKT_X2.P2, MKT_L.PL, MKT_K.PK, MKT_W.PW, MKT_PFX.PFX, I_RA.RA /;

*       We replicate the benchmark by assuming default values of
*       unity for production activities and prices, but we must 
*       explicitly specify benchmark values for the trade activities
*       because they are not unity:

X1.L=1; X2.L=1; W.L=1; P1.L=1; P2.L=1; PK.L=1; PL.L=1; PW.L=1; PFX.L=1; RA.L=200;
E2.L = 0; M1.L = 0; E1.L = 50; M2.L = 50;

HOTRADE.ITERLIM = 0;
SOLVE HOTRADE USING MCP;


* Counterfactual experiments are to levy a 5% and then a 10% import 
* tariff on X2.  10% tariff is prohibitive.

PW.FX = 1;
HOTRADE.ITERLIM = 1000;

TM2 = 0.05;
SOLVE HOTRADE USING MCP;

TM2 = 0.10;
SOLVE HOTRADE USING MCP;

$ontext

Excercises:

(i) Compare the welfare cost of tariffs in this model with the results
from a Ricardo-Viner-Jones (specific factors) model.  To do so, replace
the mobile capital stock by sector-specific capital stocks (drop PK
and add PK1 and PK2).

(ii) Multiply all of the international prices (PE1,PE2,PM1,PM2) by a
positive constant and verify that the benchmark equilibrium is undisturbed --
all that changes is that PFX changes proportionately.

$offtext
